Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(94)

Unified Diff: pkg/custom_element/test/analyzer_test.dart

Issue 20886002: add custom_element package (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: remove unused dev dep Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/custom_element/pubspec.yaml ('k') | pkg/custom_element/test/custom_element_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/custom_element/test/analyzer_test.dart
diff --git a/samples/tests/samples/standalone/time_test.dart b/pkg/custom_element/test/analyzer_test.dart
similarity index 61%
copy from samples/tests/samples/standalone/time_test.dart
copy to pkg/custom_element/test/analyzer_test.dart
index 32a8726ccaba707e59d14c9eb5589b446682c6d3..1ac251bd58449c2510ebab6d5a33948b91939785 100644
--- a/samples/tests/samples/standalone/time_test.dart
+++ b/pkg/custom_element/test/analyzer_test.dart
@@ -2,13 +2,12 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-import '../../../time/time_server.dart' as time;
+library custom_element.test.analyzer_test;
+
+import 'package:custom_element/custom_element.dart';
// @static-clean
Jennifer Messerly 2013/07/27 01:35:08 this is the magic annotation to catch warnings as
/**
* This test exists to ensure that the time sample compiles without errors.
*/
void main() {
-
}
« no previous file with comments | « pkg/custom_element/pubspec.yaml ('k') | pkg/custom_element/test/custom_element_test.dart » ('j') | no next file with comments »
@@ -2,13 +2,12 @@
// @static-clean
Jennifer Messerly 2013/07/27 01:35:08 this is the magic annotation to catch warnings as
-/**
- * This test exists to ensure that the time sample compiles without errors.
- */
+// This test ensures CustomElement compiles without errors.
void main() {

Powered by Google App Engine
This is Rietveld 408576698